@@ -118,7 +118,7 @@ async def set_switch(
 
 async def api_request(
     aiohttp_session: aiohttp.ClientSession, options: Py2NConnectionData, url: str
-) -> dict[str, Any]:
+) -> dict[str, Any] | None:
     """Perform REST call to device."""
     try:
         async with aiohttp_session.get(
@@ -145,4 +145,5 @@ async def api_request(
         _LOGGER.debug("host %s: api error: %r", options.host, err)
         raise err
 
-    return result["result"]
+    if "result" in result:
+        return result["result"]
